@@ -1,16 +1,19 @@
 package App::CharmKit::Sys;
-$App::CharmKit::Sys::VERSION = '0.008';
+$App::CharmKit::Sys::VERSION = '0.009';
 # ABSTRACT: system utilities
 
 
+use strict;
+use warnings;
 use Path::Tiny;
 use IPC::Run qw(run timeout);
 use Exporter qw(import);
 
 our @EXPORT = qw/execute
-  apt_inst
+  apt_install
   apt_upgrade
   apt_update
+  apt_add_repo
   make_dir
   remove_dir
   set_owner
@@ -18,12 +21,15 @@ our @EXPORT = qw/execute
   del_user
   spew
   slurp
-  getent/;
+  getent
+  service_control
+  service_status/;
+
 
 sub spew {
-  my $path = path(shift);
-  my $contents = shift;
-  $path->spew_utf8($contents);
+    my $path     = path(shift);
+    my $contents = shift;
+    $path->spew_utf8($contents);
 }
 
 sub slurp {
@@ -87,11 +93,37 @@ sub execute {
     };
 }
 
-sub apt_inst {
+
+
+sub apt_add_repo {
+    my $repo   = shift;
+    my $update = shift || 0;
+    my $key    = shift || undef;
+    if ($repo =~ /^(ppa:|cloud:|http|deb|cloud-archive:)/) {
+        execute(['apt-add-repository', '--yes', $repo]);
+    }
+    if ($repo =~ /^cloud:/) {
+        apt_install(['ubuntu-cloud-keyring']);
+    }
+    if ($key) {
+        execute(
+            [   'apt-key', 'adv', '--keyserver',
+                'hkp://keyserver.ubuntu.com:80',
+                '--recv', $key
+            ]
+        );
+    }
+    if ($update) {
+        apt_update();
+    }
+}
+
+sub apt_install {
     my $pkgs = shift;
     my $cmd = ['apt-get', '-qyf', 'install'];
     map { push @{$cmd}, $_ } @{$pkgs};
     my $ret = execute($cmd);
+    die $! unless $ret->{error} > 0;
     return $ret->{stdout};
 }
 
@@ -107,6 +139,24 @@ sub apt_update {
     return $ret->{stdout};
 }
 
+
+
+sub service_control {
+    my $service_name = shift;
+    my $action       = shift;
+    my $cmd          = ['service', $service_name, $action];
+    my $ret          = execute($cmd);
+    return $ret;
+}
+
+
+sub service_status {
+    my $service_name = shift;
+    my $ret = service_control($service_name, 'status');
+    return $ret->{error};
+}
+
+
 1;
 
 __END__
@@ -121,11 +171,11 @@ App::CharmKit::Sys - system utilities
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
-  use charm -sys;
+  use charm;
 
 or
 
@@ -133,7 +183,7 @@ or
 
   apt_update();
   apt_upgrade();
-  apt_inst(['nginx-common', 'redis-server']);
+  apt_install(['nginx-common', 'redis-server']);
 
 =head1 DESCRIPTION
 
@@ -185,11 +235,20 @@ Executes a local command:
    my $ret = execute($cmd);
    print $ret->{stdout};
 
-=head2 apt_inst(ARRAYREF pkgs)
+=head2 apt_add_repo(STR repo, STR key, BOOL update)
+
+Adds a archive repository or ppa. B<key> is required if adding http source.
+
+B<source> can be in the format of:
+
+  ppa:charmers/example
+  deb https://stub:key@private.example.com/ubuntu trusty main
+
+=head2 apt_install(ARRAYREF pkgs)
 
 Installs packages via apt-get
 
-   apt_inst(['nginx']);
+   apt_install(['nginx']);
 
 =head2 apt_upgrade()
 
@@ -203,6 +262,14 @@ Update repository sources
 
    apt_update();
 
+=head2 service_control(STR service_name, STR action)
+
+Controls a upstart service
+
+=head2 service_status(STR service_nae)
+
+Get running status of service
+
 =head1 AUTHOR
 
 Adam Stokes <adamjs@cpan.org>
